@@ -32,6 +32,7 @@ from sushy.resources import settings
 from sushy.resources.system import bios
 from sushy.resources.system import constants as sys_cons
 from sushy.resources.system import ethernet_interface
+from sushy.resources.system import pcie_device
 from sushy.resources.system import processor
 from sushy.resources.system import secure_boot
 from sushy.resources.system import simple_storage as sys_simple_storage
@@ -41,6 +42,8 @@ from sushy import utils
 
 LOG = logging.getLogger(__name__)
 
+EXPAND_QUERY = '?$expand=.($levels=1)'
+
 
 class ActionsField(base.CompositeField):
     reset = common.ResetActionField('#ComputerSystem.Reset')
@@ -61,6 +64,95 @@ class BootField(base.CompositeField):
 
     http_boot_uri = base.Field('HttpBootUri')
 
+    def _load(self, body, resource, nested_in=None):
+        """Load the boot field, checking Settings fallback for missing values.
+
+        Some newer BMCs move some boot values to a nested Settings field
+        which is defined by an attribute on the response body. So we need
+        to check there if any boot field values are None in the main
+        resource.
+        """
+        # Load the field normally first
+        instance = super()._load(body, resource, nested_in)
+
+        if instance is None:
+            return None
+
+        # Check if we have Settings available and any values might be missing
+        if (hasattr(resource, '_settings')
+                and resource._settings
+                and resource._settings.resource_uri):
+
+            try:
+                settings_resp = resource._conn.get(
+                    resource._settings.resource_uri)
+                settings_data = settings_resp.json()
+                settings_boot = settings_data.get('Boot', {})
+
+                if not settings_boot:
+                    return instance
+
+                # Check and populate allowed_values if missing
+                allowable_key = ('BootSourceOverrideTarget@'
+                                 'Redfish.AllowableValues')
+                if (instance.allowed_values is None
+                        and allowable_key in settings_boot):
+                    settings_allowed_values = settings_boot[allowable_key]
+                    if settings_allowed_values:
+                        instance.allowed_values = list(settings_allowed_values)
+
+                # Check and populate enabled if missing/None
+                if (instance.enabled is None
+                        and 'BootSourceOverrideEnabled' in settings_boot):
+                    enabled_value = settings_boot['BootSourceOverrideEnabled']
+                    if enabled_value:
+                        try:
+                            instance.enabled = (
+                                sys_cons.BootSourceOverrideEnabled(
+                                    enabled_value))
+                        except ValueError:
+                            pass  # Keep as None if value is not valid
+
+                # Check and populate mode if missing/None
+                if (instance.mode is None
+                        and 'BootSourceOverrideMode' in settings_boot):
+                    mode_value = settings_boot['BootSourceOverrideMode']
+                    if mode_value:
+                        try:
+                            instance.mode = sys_cons.BootSourceOverrideMode(
+                                mode_value)
+                        except ValueError:
+                            pass  # Keep as None if value is not valid
+
+                # Check and populate target if missing/None
+                if (instance.target is None
+                        and 'BootSourceOverrideTarget' in settings_boot):
+                    target_value = settings_boot['BootSourceOverrideTarget']
+                    if target_value:
+                        try:
+                            instance.target = sys_cons.BootSource(target_value)
+                        except ValueError:
+                            pass  # Keep as None if value is not valid
+
+                # Check and populate http_boot_uri if missing/None
+                if (instance.http_boot_uri is None
+                        and 'HttpBootUri' in settings_boot):
+                    instance.http_boot_uri = settings_boot['HttpBootUri']
+
+                if any([instance.allowed_values, instance.enabled,
+                        instance.mode, instance.target,
+                        instance.http_boot_uri]):
+                    LOG.debug('Retrieved boot field values from Settings '
+                              'resource for System %s',
+                              getattr(resource, 'identity', 'unknown'))
+
+            except Exception as exc:
+                LOG.warning('Failed to retrieve boot field values from '
+                            'Settings resource for System %s: %s',
+                            getattr(resource, 'identity', 'unknown'), exc)
+
+        return instance
+
 
 class BootProgressField(base.CompositeField):
 
@@ -481,7 +573,31 @@ class System(base.ResourceBase):
         :returns: `SimpleStorageCollection` instance
         """
         return sys_simple_storage.SimpleStorageCollection(
-            self._conn, utils.get_sub_resource_path_by(self, "SimpleStorage"),
+            self._conn,
+            utils.get_sub_resource_path_by(self, "SimpleStorage"),
+            redfish_version=self.redfish_version,
+            registries=self.registries, root=self.root)
+
+    @property
+    @utils.cache_it
+    def simple_storage_expanded(self):
+        """A collection of simple storage with devices expanded.
+
+        This returns a reference to `SimpleStorageCollection` instance with
+        expanded data retrieved in a single request.
+
+        It is set once when the first time it is queried. On refresh,
+        this property is marked as stale (greedy-refresh not done).
+
+        :returns: `SimpleStorageCollection` instance with expanded data
+        :raises: MissingAttributeError if 'SimpleStorage/@odata.id' field
+            is missing.
+        """
+        path = utils.get_sub_resource_path_by(self, "SimpleStorage")
+        path = f'{path}{EXPAND_QUERY}'
+
+        return sys_simple_storage.SimpleStorageCollection(
+            self._conn, path,
             redfish_version=self.redfish_version,
             registries=self.registries, root=self.root)
 
@@ -504,7 +620,32 @@ class System(base.ResourceBase):
         :returns: `StorageCollection` instance
         """
         return sys_storage.StorageCollection(
-            self._conn, utils.get_sub_resource_path_by(self, "Storage"),
+            self._conn,
+            utils.get_sub_resource_path_by(self, "Storage"),
+            redfish_version=self.redfish_version,
+            registries=self.registries, root=self.root)
+
+    @property
+    @utils.cache_it
+    def storage_expanded(self):
+        """A collection of storage subsystems with expanded data.
+
+        This returns a reference to `StorageCollection` instance with
+        additional data (e.g controllers and drives) expanded in a single
+        request.
+
+        It is set once when the first time it is queried. On refresh,
+        this property is marked as stale (greedy-refresh not done).
+
+        :returns: `StorageCollection` instance with expanded data
+        :raises: MissingAttributeError if 'Storage/@odata.id' field
+            is missing.
+        """
+        path = utils.get_sub_resource_path_by(self, "Storage")
+        path = f'{path}{EXPAND_QUERY}'
+
+        return sys_storage.StorageCollection(
+            self._conn, path,
             redfish_version=self.redfish_version,
             registries=self.registries, root=self.root)
 
@@ -558,6 +699,26 @@ class System(base.ResourceBase):
                                 registries=self.registries, root=self.root)
                 for path in paths]
 
+    @property
+    @utils.cache_it
+    def chassis_expanded(self):
+        """A list of chassis with expanded data.
+
+        Returns a list of `Chassis` objects with additional data
+        (e.g thermal and power) expanded in a single request.
+
+        :raises: MissingAttributeError if '@odata.id' field is missing.
+        :returns: A list of `Chassis` instances with expanded data
+        """
+        paths = utils.get_sub_resource_path_by(
+            self, ["Links", "Chassis"], is_collection=True)
+        paths = [f'{path}{EXPAND_QUERY}' for path in paths]
+
+        return [chassis.Chassis(self._conn, path,
+                                redfish_version=self.redfish_version,
+                                registries=self.registries, root=self.root)
+                for path in paths]
+
     @property
     @utils.cache_it
     def secure_boot(self):
@@ -585,6 +746,32 @@ class System(base.ResourceBase):
             redfish_version=self.redfish_version, registries=self.registries,
             root=self.root)
 
+    @property
+    @utils.cache_it
+    def pcie_devices(self):
+        """Property to reference PCIeDeviceCollection instance"""
+        try:
+            pcie_path = utils.get_sub_resource_path_by(self, "PCIeDevices")
+            return pcie_device.PCIeDeviceCollection(
+                self._conn, pcie_path,
+                redfish_version=self.redfish_version,
+                registries=self.registries, root=self.root)
+        except exceptions.MissingAttributeError:
+            # Check if PCIeDevices is embedded in System JSON
+            if (hasattr(self, 'json') and self.json
+                    and 'PCIeDevices' in self.json):
+                pcie_devices_data = self.json['PCIeDevices']
+                if isinstance(pcie_devices_data, list) and pcie_devices_data:
+                    return pcie_device.PCIeDeviceCollection(
+                        self._conn, "/embedded",
+                        redfish_version=self.redfish_version,
+                        registries=self.registries, root=self.root,
+                        embedded_data=pcie_devices_data)
+            return pcie_device.PCIeDeviceCollection(
+                self._conn, "/empty",
+                redfish_version=self.redfish_version,
+                registries=self.registries, root=self.root)
+
 
 class SystemCollection(base.ResourceCollectionBase):
 
