@@ -31,7 +31,7 @@ from sushy.tests.unit import base
 class BiosTestCase(base.TestCase):
 
     def setUp(self):
-        super(BiosTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/bios.json') as f:
             self.bios_json = json.load(f)
@@ -365,7 +365,7 @@ class BiosTestCase(base.TestCase):
 class BiosZTTestCase(base.TestCase):
 
     def setUp(self):
-        super(BiosZTTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/bios_zt.json') as f:
             self.bios_json = json.load(f)
@@ -375,7 +375,7 @@ class BiosZTTestCase(base.TestCase):
 
         registries = {}
         conn = mock.Mock()
-        # Note(iurygregory): re-use message registry for now.
+        # Note(iurygregory): reuse message registry for now.
         with open('sushy/tests/unit/json_samples/message_registry.json') as f:
             conn.get.return_value.json.return_value = json.load(f)
             msg_reg = message_registry.MessageRegistry(
