@@ -361,6 +361,23 @@ class SystemTestCase(base.TestCase):
                            'BootSourceOverrideTarget': 'UsbCd'}},
             etag='81802dbf61beb0bd')
 
+    def test_set_system_boot_options_supermicro_usb_cd_boot_ars111glnhr(self):
+        (self.json_doc["Boot"]
+         ["BootSourceOverrideTarget@Redfish.AllowableValues"]).append("UsbCd")
+        self.sys_inst._parse_attributes(self.json_doc)
+
+        self.sys_inst.manufacturer = "supermicro"
+        self.sys_inst.model = "ARS-111GL-NHR"
+        self.sys_inst.set_system_boot_options(
+            target=sushy.BootSource.CD,
+            enabled=sushy.BootSourceOverrideEnabled.ONCE)
+
+        self.sys_inst._conn.patch.assert_called_once_with(
+            '/redfish/v1/Systems/437XR1138R2',
+            data={'Boot': {'BootSourceOverrideEnabled': 'Once',
+                           'BootSourceOverrideTarget': 'Cd'}},
+            etag='81802dbf61beb0bd')
+
     def test_set_system_boot_options_supermicro_no_usb_cd_boot(self):
 
         self.sys_inst.manufacturer = "supermicro"
@@ -855,11 +872,11 @@ class SystemTestCase(base.TestCase):
         self.assertIsInstance(self.sys_inst.simple_storage,
                               simple_storage.SimpleStorageCollection)
 
-    def test_storage_for_missing_attr(self):
+    def test_simplestorage_for_missing_attr(self):
         self.sys_inst.json.pop('SimpleStorage')
         with self.assertRaisesRegex(
-                exceptions.MissingAttributeError, 'attribute Storage'):
-            self.sys_inst.storage
+                exceptions.MissingAttributeError, 'attribute SimpleStorage'):
+            self.sys_inst.simple_storage
 
     def test_storage(self):
         # | GIVEN |
@@ -956,6 +973,24 @@ class SystemTestCase(base.TestCase):
         self.assertEqual(
             '/redfish/v1/Chassis/1U', actual_chassis[0].path)
 
+    @mock.patch.object(chassis, 'Chassis', autospec=True)
+    def test_chassis_expanded(self, mock_chassis):
+        # Test accessing expanded chassis property
+        result = self.sys_inst.chassis_expanded
+        mock_chassis.assert_called_once_with(
+            self.conn, '/redfish/v1/Chassis/1U?$expand=.($levels=1)',
+            redfish_version=self.sys_inst.redfish_version,
+            registries=self.sys_inst.registries, root=self.sys_inst.root)
+        self.assertEqual([mock_chassis.return_value], result)
+
+    def test_chassis_missing_attr(self):
+        # Test missing chassis attribute
+        self.sys_inst._json['Links'].pop('Chassis')
+        self.assertRaisesRegex(
+            exceptions.MissingAttributeError,
+            'attribute Links/Chassis',
+            lambda: self.sys_inst.chassis)
+
     def test_get_oem_extension(self):
         # | WHEN |
         contoso_system_extn_inst = self.sys_inst.get_oem_extension('Contoso')
@@ -970,6 +1005,270 @@ class SystemTestCase(base.TestCase):
             exceptions.MissingAttributeError, 'attribute VirtualMedia'):
             self.sys_inst.virtual_media
 
+    def test_boot_field_settings_fallback_allowed_values(self):
+        """Test BootField falls back to Settings for allowed_values."""
+        # Setup: Main Boot section missing allowed_values
+        boot_data_without_allowed_values = {
+            'BootSourceOverrideEnabled': 'Once',
+            'BootSourceOverrideTarget': 'Pxe',
+            'BootSourceOverrideMode': 'UEFI'
+        }
+
+        # Settings resource with allowed_values
+        settings_data = {
+            'Boot': {
+                'BootSourceOverrideTarget@Redfish.AllowableValues': [
+                    'None', 'Pxe', 'Cd', 'Usb', 'Hdd', 'UefiHttp'
+                ]
+            }
+        }
+
+        # Mock system data without allowed_values in main Boot section
+        system_data = self.json_doc.copy()
+        system_data['Boot'] = boot_data_without_allowed_values
+
+        # Mock settings response
+        settings_response = mock.Mock()
+        settings_response.json.return_value = settings_data
+
+        # Setup system with settings
+        self.sys_inst._settings = mock.Mock()
+        self.sys_inst._settings.resource_uri = '/redfish/v1/Systems/Self/SD'
+
+        # Mock the connector to return settings data when requested
+        self.conn.get.return_value = settings_response
+
+        # Create a new boot field instance
+        boot_field = system.BootField('Boot')
+        boot_field_instance = boot_field._load(system_data, self.sys_inst)
+
+        # Verify allowed_values was populated from Settings
+        expected_values = ['None', 'Pxe', 'Cd', 'Usb', 'Hdd', 'UefiHttp']
+        self.assertEqual(expected_values, boot_field_instance.allowed_values)
+
+        # Verify Settings URI was called
+        self.conn.get.assert_called_with('/redfish/v1/Systems/Self/SD')
+
+    def test_boot_field_settings_fallback_all_fields(self):
+        """Test BootField falls back to Settings for all missing fields."""
+        # Setup: Main Boot section with minimal data
+        boot_data_minimal = {}
+
+        # Settings resource with all boot values
+        settings_data = {
+            'Boot': {
+                'BootSourceOverrideTarget@Redfish.AllowableValues': [
+                    'None', 'Pxe', 'Cd', 'UefiHttp'
+                ],
+                'BootSourceOverrideEnabled': 'Continuous',
+                'BootSourceOverrideMode': 'Legacy',
+                'BootSourceOverrideTarget': 'Cd',
+                'HttpBootUri': 'https://example.com/boot.iso'
+            }
+        }
+
+        # Mock system data with empty Boot section
+        system_data = self.json_doc.copy()
+        system_data['Boot'] = boot_data_minimal
+
+        # Mock settings response
+        settings_response = mock.Mock()
+        settings_response.json.return_value = settings_data
+
+        # Setup system with settings
+        self.sys_inst._settings = mock.Mock()
+        self.sys_inst._settings.resource_uri = '/redfish/v1/Systems/Self/SD'
+
+        # Mock the connector to return settings data when requested
+        self.conn.get.return_value = settings_response
+
+        # Create a new boot field instance
+        boot_field = system.BootField('Boot')
+        boot_field_instance = boot_field._load(system_data, self.sys_inst)
+
+        # Verify all values were populated from Settings
+        self.assertEqual(['None', 'Pxe', 'Cd', 'UefiHttp'],
+                         boot_field_instance.allowed_values)
+        self.assertEqual(sushy.BootSourceOverrideEnabled.CONTINUOUS,
+                         boot_field_instance.enabled)
+        self.assertEqual(sushy.BootSourceOverrideMode.LEGACY,
+                         boot_field_instance.mode)
+        self.assertEqual(sushy.BootSource.CD, boot_field_instance.target)
+        self.assertEqual('https://example.com/boot.iso',
+                         boot_field_instance.http_boot_uri)
+
+    def test_boot_field_settings_fallback_partial_override(self):
+        """Test BootField only falls back for None values, not existing."""
+        # Setup: Main Boot section with some values
+        boot_data_partial = {
+            'BootSourceOverrideEnabled': 'Once',
+            'BootSourceOverrideTarget': 'Pxe',
+            # Missing allowed_values, mode, and http_boot_uri
+        }
+
+        # Settings resource with values
+        settings_data = {
+            'Boot': {
+                'BootSourceOverrideTarget@Redfish.AllowableValues': [
+                    'None', 'Pxe', 'Cd'
+                ],
+                'BootSourceOverrideEnabled': 'Continuous',  # No override
+                'BootSourceOverrideMode': 'UEFI',  # Should be used
+                'HttpBootUri': 'https://example.com/boot.iso'  # Should be used
+            }
+        }
+
+        # Mock system data with partial Boot section
+        system_data = self.json_doc.copy()
+        system_data['Boot'] = boot_data_partial
+
+        # Mock settings response
+        settings_response = mock.Mock()
+        settings_response.json.return_value = settings_data
+
+        # Setup system with settings
+        self.sys_inst._settings = mock.Mock()
+        self.sys_inst._settings.resource_uri = '/redfish/v1/Systems/Self/SD'
+
+        # Mock the connector to return settings data when requested
+        self.conn.get.return_value = settings_response
+
+        # Create a new boot field instance
+        boot_field = system.BootField('Boot')
+        boot_field_instance = boot_field._load(system_data, self.sys_inst)
+
+        # Verify existing values were NOT overridden
+        self.assertEqual(sushy.BootSourceOverrideEnabled.ONCE,
+                         boot_field_instance.enabled)
+        self.assertEqual(sushy.BootSource.PXE, boot_field_instance.target)
+
+        # Verify missing values were populated from Settings
+        self.assertEqual(['None', 'Pxe', 'Cd'],
+                         boot_field_instance.allowed_values)
+        self.assertEqual(sushy.BootSourceOverrideMode.UEFI,
+                         boot_field_instance.mode)
+        self.assertEqual('https://example.com/boot.iso',
+                         boot_field_instance.http_boot_uri)
+
+    def test_boot_field_no_settings_resource(self):
+        """Test BootField works normally when no Settings resource exists."""
+        # Setup: System without Settings resource
+        self.sys_inst._settings = None
+
+        # Use original test data (has allowed_values in main Boot section)
+        boot_field = system.BootField('Boot')
+        boot_field_instance = boot_field._load(self.json_doc, self.sys_inst)
+
+        # Verify normal loading behavior
+        expected_values = ["None", "Pxe", "Cd", "Usb", "Hdd", "BiosSetup",
+                           "Utilities", "Diags", "SDCard", "UefiTarget",
+                           "UefiHttp"]
+        self.assertEqual(expected_values, boot_field_instance.allowed_values)
+        self.assertEqual(sushy.BootSourceOverrideEnabled.ONCE,
+                         boot_field_instance.enabled)
+
+    @mock.patch.object(system.LOG, 'warning', autospec=True)
+    def test_boot_field_settings_fetch_error(self, mock_log):
+        """Test BootField handles Settings fetch errors gracefully."""
+        # Setup: Main Boot section missing allowed_values
+        boot_data_without_allowed_values = {
+            'BootSourceOverrideEnabled': 'Once',
+            'BootSourceOverrideTarget': 'Pxe'
+        }
+
+        system_data = self.json_doc.copy()
+        system_data['Boot'] = boot_data_without_allowed_values
+
+        # Setup system with settings but make the call fail
+        self.sys_inst._settings = mock.Mock()
+        self.sys_inst._settings.resource_uri = '/redfish/v1/Systems/Self/SD'
+
+        # Mock connector to raise exception on Settings fetch
+        self.conn.get.side_effect = Exception("Network error")
+
+        # Create a new boot field instance
+        boot_field = system.BootField('Boot')
+        boot_field_instance = boot_field._load(system_data, self.sys_inst)
+
+        # Verify the instance was still created but without fallback values
+        self.assertIsNotNone(boot_field_instance)
+        self.assertIsNone(boot_field_instance.allowed_values)
+
+        # Verify warning was logged
+        mock_log.assert_called_once()
+        self.assertIn('Failed to retrieve boot field values',
+                      str(mock_log.call_args))
+
+    def test_boot_field_settings_invalid_enum_values(self):
+        """Test BootField handles invalid enum values gracefully."""
+        # Setup: Main Boot section with minimal data
+        boot_data_minimal = {}
+
+        # Settings resource with invalid enum values
+        settings_data = {
+            'Boot': {
+                'BootSourceOverrideEnabled': 'InvalidValue',
+                'BootSourceOverrideMode': 'BadMode',
+                'BootSourceOverrideTarget': 'UnknownTarget'
+            }
+        }
+
+        system_data = self.json_doc.copy()
+        system_data['Boot'] = boot_data_minimal
+
+        # Mock settings response
+        settings_response = mock.Mock()
+        settings_response.json.return_value = settings_data
+
+        # Setup system with settings
+        self.sys_inst._settings = mock.Mock()
+        self.sys_inst._settings.resource_uri = '/redfish/v1/Systems/Self/SD'
+
+        # Mock the connector to return settings data when requested
+        self.conn.get.return_value = settings_response
+
+        # Create a new boot field instance
+        boot_field = system.BootField('Boot')
+        boot_field_instance = boot_field._load(system_data, self.sys_inst)
+
+        # Verify invalid enum values resulted in None (graceful handling)
+        self.assertIsNone(boot_field_instance.enabled)
+        self.assertIsNone(boot_field_instance.mode)
+        self.assertIsNone(boot_field_instance.target)
+
+    def test_storage_for_missing_attr(self):
+        self.sys_inst.json.pop('Storage')
+        with self.assertRaisesRegex(
+                exceptions.MissingAttributeError, 'attribute Storage'):
+            self.sys_inst.storage
+
+    @mock.patch('sushy.resources.system.storage.storage.StorageCollection',
+                autospec=True)
+    def test_storage_expanded(self, mock_storage_collection):
+        # Test accessing expanded storage property
+        result = self.sys_inst.storage_expanded
+        mock_storage_collection.assert_called_once_with(
+            self.conn,
+            '/redfish/v1/Systems/437XR1138R2/Storage?$expand=.($levels=1)',
+            redfish_version='1.0.2',
+            registries=None,
+            root=None)
+        self.assertIsNotNone(result)
+
+    @mock.patch('sushy.resources.system.simple_storage.'
+                'SimpleStorageCollection', autospec=True)
+    def test_simple_storage_expanded(self, mock_simple_storage_collection):
+        # Test accessing expanded simple_storage property
+        result = self.sys_inst.simple_storage_expanded
+        mock_simple_storage_collection.assert_called_once_with(
+            self.conn,
+            '/redfish/v1/Systems/437XR1138R2/SimpleStorage?'
+            '$expand=.($levels=1)',
+            redfish_version='1.0.2',
+            registries=None,
+            root=None)
+        self.assertIsNotNone(result)
+
 
 class SystemWithVirtualMedia(base.TestCase):
 
